@@ -6,7 +6,7 @@ from .POLQA.polqa_client import polqa_client_test
 from .SDR.SDR import cal_sdr
 from .STI.cal_sti import cal_sti
 from .STOI.STOI import *
-from .resample.resampler import resample
+from .resample.resampler import resample,restruct
 from .timeAligment.time_align import cal_delay
 from .formatConvert.wav_pcm import get_data_array
 from .SNR_ESTIMATION.MATCH_SIG import match_sig
