@@ -13,7 +13,7 @@ from SDR.SDR import cal_sdr
 from STI.cal_sti import cal_sti
 from STOI.STOI import cal_stoi
 from PEAQ.PEAQ import cal_peaq
-from resample.resampler import resample
+from resample.resampler import resample,restruct
 from timeAligment.time_align import cal_delay
 import os
 import wave
